#ifndef HARDWARE_H
#define HARDWARE_H

#include <io.h>
#include <signal.h>
#include <iomacros.h>


//PINS
//PORT1

//PORT2
#define DAT             BIT0
#define CLK             BIT1
#define LED             BIT5

//PORT3
#define LCD_RS          BIT1
#define LCD_RW          BIT2
#define LCD_E           BIT3
#define LCD_D4          BIT4
#define LCD_D5          BIT5
#define LCD_D6          BIT6
#define LCD_D7          BIT7


//for the lcd.c module
#define LCDOUT          P3OUT
#define LCDDIR          P3DIR
#define LCDIN           P3IN
//customize this if your MSP runs at different speed.
#define LCDDELAY1MS     750                     // ~1ms @750kHz


//Port Output Register 'P1OUT, P2OUT':
#define P1OUT_INIT      0                       // Init Output data of port1
#define P2OUT_INIT      0                       // Init Output data of port2
#define P3OUT_INIT      0                       // Init Output data of port3

//Port Direction Register 'P1DIR, P2DIR':
#define P1DIR_INIT      0xff                    // Init of Port1 Data-Direction Reg (Out=1 / Inp=0)
#define P2DIR_INIT      LED                     // Init of Port2 Data-Direction Reg (Out=1 / Inp=0)
#define P3DIR_INIT      0xff                    // Init of Port3 Data-Direction Reg (Out=1 / Inp=0)

//Selection of Port or Module -Function on the Pins 'P1SEL, P2SEL'
#define P1SEL_INIT      0                       // P1-Modules:
#define P2SEL_INIT      0                       // P2-Modules:
#define P3SEL_INIT      0                       // P3-Modules:

//Interrupt capabilities of P1 and P2
#define P1IE_INIT       0                       // Interrupt Enable (0=dis 1=enabled)
#define P2IE_INIT       CLK                     // Interrupt Enable (0=dis 1=enabled)
#define P1IES_INIT      0                       // Interrupt Edge Select (0=pos 1=neg)
#define P2IES_INIT      CLK                     // Interrupt Edge Select (0=pos 1=neg)

#define IE_INIT         0
#define WDTCTL_INIT     WDTPW|WDTHOLD

#define TACTL_INIT      TASSEL0|TACLR|ID_3      //ACLK, /8
#define ONESECOND       512                     //32768/8/16

/**********************************************************************
*    makros for easy led control                                      *
***********************************************************************/
#define mcRedOn()        (P2OUT |= 0x01)     /* power on red */
#define mcGreenOn()      (P2OUT |= 0x02)     /*  */
#define mcBlueOn()       (P2OUT |= 0x04)
#define mcRedOff()       (P2OUT &= ~0x01)    /* led off */
#define mcGreenOff()     (P2OUT &= ~0x02)
#define mcBlueOff()      (P2OUT &= ~0x04)

typedef unsigned char byte;                       /* vorzeichenlose 8-Bit-Zahl */
typedef unsigned int word;                        /* vorzeichenlose 16-Bit-Zahl */
typedef signed char int8;                         /* vorzeichenbehaftete 8-Bit-Zahl */
typedef signed int int16;                         /* vorzeichenbehaftete 16-Bit-Zahl */
typedef byte bool;                                /* True/False Aussage */
typedef unsigned long dword;                      /* Long-Zahl */

#define True                  1
#define False                 0

#define On                    1
#define Off                   0

#define ONESECOND       512                     //32768/8/16
#define DINT	_DINT
#define EINT	_EINT
//#define _DINT()	asm("dint")
//#define _EINT()	asm("eint")

#endif //HARDWARE_H
